==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LastWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { LastWeekExpressionDescription } from "./LastWeekExpressionDescription";
/**
 * @hidden
 */
var LastWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LastWeekExpressionDescriptionMetadata, _super);
    function LastWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastWeekExpressionDescriptionMetadata.b = function (a) {
        if (LastWeekExpressionDescriptionMetadata.a == null) {
            LastWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastWeekExpressionDescriptionMetadata.c(LastWeekExpressionDescriptionMetadata.a);
        }
        if (a.j(LastWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(LastWeekExpressionDescriptionMetadata.a);
    };
    LastWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    LastWeekExpressionDescriptionMetadata.d = function (a) {
        LastWeekExpressionDescriptionMetadata.b(a);
        a.aa("LastWeekExpression", function () { return new LastWeekExpressionDescription(); });
        a.z("LastWeekExpression", LastWeekExpressionDescriptionMetadata.a);
    };
    LastWeekExpressionDescriptionMetadata.$t = markType(LastWeekExpressionDescriptionMetadata, 'LastWeekExpressionDescriptionMetadata');
    LastWeekExpressionDescriptionMetadata.a = null;
    return LastWeekExpressionDescriptionMetadata;
}(Base));
export { LastWeekExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/LastWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OffsettableWeekExpressionDescriptionMetadata } from "./OffsettableWeekExpressionDescriptionMetadata";
import { LastWeekExpressionDescription } from "./LastWeekExpressionDescription";
/**
 * @hidden
 */
var LastWeekExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LastWeekExpressionDescriptionMetadata, _super);
    function LastWeekExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastWeekExpressionDescriptionMetadata.b = function (a) {
        if (LastWeekExpressionDescriptionMetadata.a == null) {
            LastWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastWeekExpressionDescriptionMetadata.c(LastWeekExpressionDescriptionMetadata.a);
        }
        if (a.k(LastWeekExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(LastWeekExpressionDescriptionMetadata.a);
    };
    LastWeekExpressionDescriptionMetadata.c = function (a) {
        OffsettableWeekExpressionDescriptionMetadata.c(a);
    };
    LastWeekExpressionDescriptionMetadata.d = function (a) {
        LastWeekExpressionDescriptionMetadata.b(a);
        a.ac("LastWeekExpression", function () { return new LastWeekExpressionDescription(); });
        a.ab("LastWeekExpression", LastWeekExpressionDescriptionMetadata.a);
    };
    LastWeekExpressionDescriptionMetadata.$t = markType(LastWeekExpressionDescriptionMetadata, 'LastWeekExpressionDescriptionMetadata');
    LastWeekExpressionDescriptionMetadata.a = null;
    return LastWeekExpressionDescriptionMetadata;
}(Base));
export { LastWeekExpressionDescriptionMetadata };
